package com.ruoyi.system.service;

import java.util.List;
import com.ruoyi.system.domain.EpsTrafficData;

/**
 * 流量相关数据Service接口
 * 
 * @author gyt
 * @date 2025-08-12
 */
public interface IEpsTrafficDataService 
{
    /**
     * 查询流量相关数据
     * 
     * @param id 流量相关数据主键
     * @return 流量相关数据
     */
    public EpsTrafficData selectEpsTrafficDataById(Long id);

    /**
     * 查询流量相关数据列表
     * 
     * @param epsTrafficData 流量相关数据
     * @return 流量相关数据集合
     */
    public List<EpsTrafficData> selectEpsTrafficDataList(EpsTrafficData epsTrafficData);

    /**
     * 新增流量相关数据
     * 
     * @param epsTrafficData 流量相关数据
     * @return 结果
     */
    public int insertEpsTrafficData(EpsTrafficData epsTrafficData);

    /**
     * 修改流量相关数据
     * 
     * @param epsTrafficData 流量相关数据
     * @return 结果
     */
    public int updateEpsTrafficData(EpsTrafficData epsTrafficData);

    /**
     * 批量删除流量相关数据
     * 
     * @param ids 需要删除的流量相关数据主键集合
     * @return 结果
     */
    public int deleteEpsTrafficDataByIds(Long[] ids);

    /**
     * 删除流量相关数据信息
     * 
     * @param id 流量相关数据主键
     * @return 结果
     */
    public int deleteEpsTrafficDataById(Long id);
}
