package com.ruoyi.system.controller;

import java.util.List;
import java.io.IOException;
import javax.servlet.http.HttpServletResponse;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.PutMapping;
import org.springframework.web.bind.annotation.DeleteMapping;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;
import com.ruoyi.common.log.annotation.Log;
import com.ruoyi.common.log.enums.BusinessType;
import com.ruoyi.common.security.annotation.RequiresPermissions;
import com.ruoyi.system.domain.EpsTrafficData;
import com.ruoyi.system.service.IEpsTrafficDataService;
import com.ruoyi.common.core.web.controller.BaseController;
import com.ruoyi.common.core.web.domain.AjaxResult;
import com.ruoyi.common.core.utils.poi.ExcelUtil;
import com.ruoyi.common.core.web.page.TableDataInfo;

/**
 * 流量相关数据Controller
 * 
 * @author gyt
 * @date 2025-08-12
 */
@RestController
@RequestMapping("/data")
public class EpsTrafficDataController extends BaseController
{
    @Autowired
    private IEpsTrafficDataService epsTrafficDataService;

    /**
     * 查询流量相关数据列表
     */
    @RequiresPermissions("system:data:list")
    @GetMapping("/list")
    public TableDataInfo list(EpsTrafficData epsTrafficData)
    {
        startPage();
        List<EpsTrafficData> list = epsTrafficDataService.selectEpsTrafficDataList(epsTrafficData);
        return getDataTable(list);
    }

    /**
     * 导出流量相关数据列表
     */
    @RequiresPermissions("system:data:export")
    @Log(title = "流量相关数据", businessType = BusinessType.EXPORT)
    @PostMapping("/export")
    public void export(HttpServletResponse response, EpsTrafficData epsTrafficData)
    {
        List<EpsTrafficData> list = epsTrafficDataService.selectEpsTrafficDataList(epsTrafficData);
        ExcelUtil<EpsTrafficData> util = new ExcelUtil<EpsTrafficData>(EpsTrafficData.class);
        util.exportExcel(response, list, "流量相关数据数据");
    }

    /**
     * 获取流量相关数据详细信息
     */
    @RequiresPermissions("system:data:query")
    @GetMapping(value = "/{id}")
    public AjaxResult getInfo(@PathVariable("id") Long id)
    {
        return success(epsTrafficDataService.selectEpsTrafficDataById(id));
    }

    /**
     * 新增流量相关数据
     */
    @RequiresPermissions("system:data:add")
    @Log(title = "流量相关数据", businessType = BusinessType.INSERT)
    @PostMapping
    public AjaxResult add(@RequestBody EpsTrafficData epsTrafficData)
    {
        return toAjax(epsTrafficDataService.insertEpsTrafficData(epsTrafficData));
    }

    /**
     * 修改流量相关数据
     */
    @RequiresPermissions("system:data:edit")
    @Log(title = "流量相关数据", businessType = BusinessType.UPDATE)
    @PutMapping
    public AjaxResult edit(@RequestBody EpsTrafficData epsTrafficData)
    {
        return toAjax(epsTrafficDataService.updateEpsTrafficData(epsTrafficData));
    }

    /**
     * 删除流量相关数据
     */
    @RequiresPermissions("system:data:remove")
    @Log(title = "流量相关数据", businessType = BusinessType.DELETE)
	@DeleteMapping("/{ids}")
    public AjaxResult remove(@PathVariable Long[] ids)
    {
        return toAjax(epsTrafficDataService.deleteEpsTrafficDataByIds(ids));
    }
}
